@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Administration Scripts
-# Copyright (c) 2008-2015 Hive Solutions Lda.
+# Copyright (c) 2008-2016 Hive Solutions Lda.
 #
 # This file is part of Hive Administration Scripts.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -49,6 +49,12 @@ configurations = (
             "-moz-animation",
             "-khtml-animation",
             "-webkit-animation",
+            "animation-delay",
+            "-o-animation-delay",
+            "-ms-animation-delay",
+            "-moz-animation-delay",
+            "-khtml-animation-delay",
+            "-webkit-animation-delay",
             "animation-duration",
             "-o-animation-duration",
             "-ms-animation-duration",
@@ -63,6 +69,7 @@ configurations = (
             "-webkit-animation-name",
             "appearance",
             "-o-appearance",
+            "-ms-appearance",
             "-moz-appearance",
             "-khtml-appearance",
             "-webkit-appearance",
@@ -71,6 +78,7 @@ configurations = (
             "-o-backface-visibility",
             "-ms-backface-visibility",
             "-moz-backface-visibility",
+            "-khtml-backface-visibility",
             "-webkit-backface-visibility",
             "background",
             "background-attachment",
@@ -78,9 +86,11 @@ configurations = (
             "-o-background-clip",
             "-ms-background-clip",
             "-moz-background-clip",
+            "-khtml-background-clip",
             "-webkit-background-clip",
             "background-color",
             "background-image",
+            "background-origin",
             "background-position",
             "background-position-x",
             "background-position-y",
@@ -93,11 +103,13 @@ configurations = (
             "-o-border-bottom-left-radius",
             "-ms-border-bottom-left-radius",
             "-moz-border-bottom-left-radius",
+            "-khtml-border-bottom-left-radius",
             "-webkit-border-bottom-left-radius",
             "border-bottom-right-radius",
             "-o-border-bottom-right-radius",
             "-ms-border-bottom-right-radius",
             "-moz-border-bottom-right-radius",
+            "-khtml-border-bottom-right-radius",
             "-webkit-border-bottom-right-radius",
             "border-bottom-style",
             "border-bottom-width",
@@ -126,11 +138,13 @@ configurations = (
             "border-top",
             "border-top-color",
             "border-top-left-radius",
+            "-o-border-top-left-radius",
             "-ms-border-top-left-radius",
             "-moz-border-top-left-radius",
             "-khtml-border-top-left-radius",
             "-webkit-border-top-left-radius",
             "border-top-right-radius",
+            "-o-border-top-right-radius",
             "-ms-border-top-right-radius",
             "-moz-border-top-right-radius",
             "-khtml-border-top-right-radius",
@@ -140,10 +154,16 @@ configurations = (
             "border-width",
             "bottom",
             "box-shadow",
+            "-o-box-shadow",
+            "-ms-box-shadow",
             "-moz-box-shadow",
+            "-khtml-box-shadow",
             "-webkit-box-shadow",
             "box-sizing",
+            "-o-box-sizing",
+            "-ms-box-sizing",
             "-moz-box-sizing",
+            "-khtml-box-sizing",
             "-webkit-box-sizing",
             "caption-side",
             "clear",
@@ -182,8 +202,10 @@ configurations = (
             "font-family",
             "font-size",
             "font-size-adjust",
+            "font-smooth",
             "font-smoothing",
             "-o-font-smoothing",
+            "-ms-font-smoothing",
             "-moz-font-smoothing",
             "-khtml-font-smoothing",
             "-webkit-font-smoothing",
@@ -193,8 +215,10 @@ configurations = (
             "font",
             "height",
             "hyphens",
+            "-o-hyphens",
             "-ms-hyphens",
             "-moz-hyphens",
+            "-khtml-hyphens",
             "-webkit-hyphens",
             "left",
             "letter-spacing",
@@ -276,6 +300,7 @@ configurations = (
             "-o-tap-highlight-color",
             "-ms-tap-highlight-color",
             "-moz-tap-highlight-color",
+            "-khtml-tap-highlight-color",
             "-webkit-tap-highlight-color",
             "text-align",
             "text-decoration",
@@ -283,55 +308,70 @@ configurations = (
             "-o-text-fill-color",
             "-ms-text-fill-color",
             "-moz-text-fill-color",
+            "-khtml-text-fill-color",
             "-webkit-text-fill-color",
             "text-indent",
             "text-overflow",
             "text-shadow",
+            "-o-text-shadow",
+            "-ms-text-shadow",
+            "-moz-text-shadow",
+            "-khtml-text-shadow",
+            "-webkit-text-shadow",
             "text-transform",
             "top",
             "touch-callout",
             "-o-touch-callout",
             "-ms-touch-callout",
             "-moz-touch-callout",
+            "-khtml-touch-callout",
             "-webkit-touch-callout",
             "transform",
             "-o-transform",
             "-ms-transform",
             "-moz-transform",
+            "-khtml-transform",
             "-webkit-transform",
             "transform-origin",
             "-o-transform-origin",
             "-ms-transform-origin",
             "-moz-transform-origin",
+            "-khtml-transform-origin",
             "-webkit-transform-origin",
             "transform-style",
             "-o-transform-style",
             "-ms-transform-style",
             "-moz-transform-style",
+            "-khtml-transform-style",
             "-webkit-transform-style",
             "transition",
             "-o-transition",
             "-ms-transition",
             "-moz-transition",
+            "-khtml-transition",
             "-webkit-transition",
             "transition-delay",
             "-o-transition-delay",
             "-ms-transition-delay",
             "-moz-transition-delay",
+            "-khtml-transition-delay",
             "-webkit-transition-delay",
             "transition-duration",
             "-o-transition-duration",
             "-ms-transition-duration",
             "-moz-transition-duration",
+            "-khtml-transition-duration",
             "-webkit-transition-duration",
             "transition-timing-function",
             "-o-transition-timing-function",
             "-ms-transition-timing-function",
             "-moz-transition-timing-function",
+            "-khtml-transition-timing-function",
             "-webkit-transition-timing-function",
             "unicode-bidi",
             "user-select",
             "-o-user-select",
+            "-ms-user-select",
             "-moz-user-select",
             "-khtml-user-select",
             "-webkit-user-select",
